@@ -1,5 +1,5 @@
 package Email::Sender::Transport::Test;
-our $VERSION = '0.091560_001';
+our $VERSION = '0.091560_002';
 
 use Moose;
 with 'Email::Sender::Transport';
@@ -8,6 +8,7 @@ with 'Email::Sender::Transport';
 use Email::Sender::Failure::Multi;
 use Email::Sender::Success::Partial;
 
+
 has allow_partial_success => (is => 'ro', isa => 'Bool', default => 0);
 
 sub recipient_failure { }
@@ -91,7 +92,50 @@ Email::Sender::Transport::Test - deliver mail in memory for testing
 
 =head1 VERSION
 
-version 0.091560_001
+version 0.091560_002
+
+=head1 DESCRIPTION
+
+This transport is meant for testing email deliveries in memory.  It will store
+a record of any delivery made so that they can be inspected afterward.
+
+=for Pod::Coverage recipient_failure delivery_failure
+
+By default, the Test transport will not allow partial success and will always
+succeed.  It can be made to fail predictably, however, if it is extended and
+its C<recipient_failure> or C<delivery_failure> methods are overridden.  These
+methods are called as follows:
+
+  $self->delivery_failure($email, $envelope);
+
+  $self->recipient_failure($to);
+
+If they return true, the sending will fail.  If the transport was created with
+a true C<allow_partial_success> attribute, recipient failures can cause partial
+success to be returned.
+
+For more flexible failure modes, you can override more aggressively or can use
+L<Email::Sender::Transport::Failable>.
+
+=for Pod::Coverage clear_deliveries
+
+This attribute stores an arrayref of all the deliveries made via the transport.
+It can be emptied by calling C<clear_deliveries>.
+
+Each delivery is a hashref, in the following format:
+
+  {
+    email     => $email,
+    envelope  => $envelope,
+    successes => \@ok_rcpts,
+    failures  => \@failures,
+  }
+
+Both successful and failed deliveries are stored.
+
+=head1 ATTRIBUTES
+
+=head2 deliveries
 
 =head1 AUTHOR
 
